@@ -41,7 +41,7 @@ if (nargin ~= 1)
     return
 endif
 
-x = x & infsup (-1, 1);
+x = intersect (x, infsup (-1, 1));
 
 ## acos is monotonically decreasing from (-1, pi) to (+1, 0)
 l = mpfr_function_d ('acos', -inf, x.sup);
@@ -59,18 +59,18 @@ endfunction
 %! assert (acos (infsup ()) == infsup ());
 %!test "Singleton intervals";
 %! assert (acos (infsup (-1)) == infsup ("pi"));
-%! assert (subset (acos (infsup (-.5)), (infsup ("pi") / 2) | infsup ("pi")));
+%! assert (subset (acos (infsup (-.5)), union ((infsup ("pi") / 2), infsup ("pi"))));
 %! assert (acos (infsup (0)) == infsup ("pi") / 2);
-%! assert (subset (acos (infsup (.5)), (infsup ("pi") / 2) | infsup (0)));
+%! assert (subset (acos (infsup (.5)), union ((infsup ("pi") / 2), infsup (0))));
 %! assert (acos (infsup (1)) == infsup (0));
 %!test "Bounded intervals";
-%! assert (acos (infsup (-1, 0)) == ((infsup ("pi") / 2) | infsup ("pi")));
-%! assert (acos (infsup (0, 1)) == ((infsup ("pi") / 2) | infsup (0)));
+%! assert (acos (infsup (-1, 0)) == union ((infsup ("pi") / 2), infsup ("pi")));
+%! assert (acos (infsup (0, 1)) == union ((infsup ("pi") / 2), infsup (0)));
 %! assert (acos (infsup (-1, 1)) == infsup (0, "pi"));
 %! assert (acos (infsup (-2, 2)) == infsup (0, "pi"));
 %!test "Unbounded intervals";
-%! assert (acos (infsup (0, inf)) == ((infsup ("pi") / 2) | infsup (0)));
-%! assert (acos (infsup (-inf, 0)) == ((infsup ("pi") / 2) | infsup ("pi")));
+%! assert (acos (infsup (0, inf)) == union ((infsup ("pi") / 2), infsup (0)));
+%! assert (acos (infsup (-inf, 0)) == union ((infsup ("pi") / 2), infsup ("pi")));
 %! assert (acos (infsup (-inf, inf)) == infsup (0, "pi"));
 %!test "from the documentation string";
 %! assert (acos (infsup (.5)) == "[0x1.0C152382D7365, 0x1.0C152382D7366]");
