@@ -24,7 +24,7 @@
 ## @example
 ## @group
 ## asin (infsup (.5))
-##   @result{} [.5235987755982988, .523598775598299]
+##   @result{} [0.5235987755982988, 0.523598775598299]
 ## @end group
 ## @end example
 ## @seealso{@@infsup/sin}
@@ -41,7 +41,7 @@ if (nargin ~= 1)
     return
 endif
 
-x = x & infsup (-1, 1);
+x = intersect (x, infsup (-1, 1));
 
 ## asin is monotonically increasing from (-1, -pi/2) to (1, pi/2)
 l = mpfr_function_d ('asin', -inf, x.inf);
