@@ -24,7 +24,7 @@
 ## @example
 ## @group
 ## atanh (infsup (.5))
-##   @result{} [.5493061443340547, .5493061443340549]
+##   @result{} [0.5493061443340547, 0.5493061443340549]
 ## @end group
 ## @end example
 ## @seealso{@@infsup/tanh}
@@ -41,7 +41,7 @@ if (nargin ~= 1)
     return
 endif
 
-x = x & infsup (-1, 1);
+x = intersect (x, infsup (-1, 1));
 
 ## atanh is monotonically increasing between (-1, -inf) and (1, inf)
 l = mpfr_function_d ('atanh', -inf, x.inf);
