@@ -28,7 +28,7 @@
 ## @example
 ## @group
 ## cosrev (infsup (0), infsup (6, 9))
-##   @result {} [7.8539816339744827, 7.8539816339744846]
+##   @result {} [7.853981633974482, 7.853981633974485]
 ## @end group
 ## @end example
 ## @seealso{@@infsup/cos}
@@ -82,7 +82,7 @@ else
     else
         arccosineshifted = (infsup (n) + 1) * pi - arccosine;
     endif
-    if (not (isempty (x & arccosineshifted)))
+    if (not (isempty (intersect (x, arccosineshifted))))
         u = min (x.sup, arccosineshifted.sup);
     else
         m = mpfr_function_d ('minus', +inf, n, 1);
@@ -105,7 +105,7 @@ else
     else
         arccosineshifted = (infsup (n) + 1) * pi - arccosine;
     endif
-    if (not (isempty (x & arccosineshifted)))
+    if (not (isempty (intersect (x, arccosineshifted))))
         l = max (x.inf, arccosineshifted.inf);
     else
         m = mpfr_function_d ('plus', -inf, n, 1);
@@ -120,7 +120,7 @@ endif
 if (l > u)
     result = infsup ();
 else
-    result = x & infsup (l, u);
+    result = intersect (x, infsup (l, u));
 endif
 
 endfunction
