@@ -28,7 +28,7 @@
 ## x = infsup (2, 3);
 ## y = infsup (1, 2);
 ## x == y
-##   @result{} False
+##   @result{} 0
 ## @end group
 ## @end example
 ## @seealso{@@infsup/subset, @@infsup/interior, @@infsup/disjoint}
@@ -49,6 +49,10 @@ if (not (isa (a, "infsup")))
 endif
 if (not (isa (b, "infsup")))
     b = infsup (b);
+elseif (isa (b, "infsupdec"))
+    ## Workaround for bug #42735
+    result = eq (a, b);
+    return
 endif
 
 result = (a.inf == b.inf & a.sup == b.sup);
