@@ -52,12 +52,12 @@
 ## fzero (f, infsup ("[-10, 10]"), df)
 ##   @result{} 6×1 interval vector
 ##    
-##       [-7.8539816339744837, -7.8539816339744827]
-##       [-4.7123889803846906, -4.7123889803846896]
+##         [-7.853981633974484, -7.853981633974482]
+##         [-4.712388980384691, -4.712388980384689]
 ##       [-1.5707963267948968, -1.5707963267948965]
 ##         [1.5707963267948965, 1.5707963267948968]
-##         [4.7123889803846896, 4.7123889803846906]
-##         [7.8539816339744827, 7.8539816339744837]
+##           [4.712388980384689, 4.712388980384691]
+##           [7.853981633974482, 7.853981633974484]
 ## fzero ("sqr", infsup ("[Entire]"))
 ##   @result{} [-2.2227587494850775e-162, +2.2227587494850775e-162]
 ## @end group
@@ -138,8 +138,8 @@ if (not (isempty (df)))
         ## Function evaluated outside of its domain
         a = x0;
     else
-        a = x0 & (m - a);
-        b = x0 & (m - b);
+        a = intersect (x0, m - a);
+        b = intersect (x0, m - b);
         if (isempty (a))
             [a, b] = deal (b, a);
         endif
@@ -164,7 +164,7 @@ if ((eq (x0, a) || isempty (b)) && not (issingleton (a)) && not (isempty (a)))
         ## When the interval is small, this algorithm will choose
         ## approximately mid (a).
         s = sign (a);
-        s = inf ((s & 1) | (s & -1));
+        s = inf (union (intersect (s, 1), intersect (s, -1)));
         m = s .* min (realmax (), pow2 (max (-1074, mid (log2 (abs (a))))));
         if (not (ismember (m, a)))
             ## Fallback, if computation fails
