@@ -49,6 +49,10 @@
 ## tight enclosure will be computed.  int64 and uint64 numbers of high
 ## magnitude (> 2^53) can also be affected from precision loss.
 ##
+## For the creation of interval matrices, arguments may be provided as (1) cell 
+## arrays with arbitrary/mixed types, (2) numeric matrices, or (3) string
+## column vectors.  Scalar values do broadcast.
+##
 ## Non-standard behavior: This class constructor is not described by IEEE 1788,
 ## however it implements both IEEE 1788 functions numsToInterval and
 ## textToInterval.
@@ -62,17 +66,17 @@
 ## infsup (2, 3)
 ##   @result{} [2, 3]
 ## infsup ("0.1")
-##   @result{} [.09999999999999999, .10000000000000001]
+##   @result{} [0.09999999999999999, 0.1000000000000001]
 ## infsup ("0.1", "0.2")
-##   @result{} [.09999999999999999, .20000000000000002]
+##   @result{} [0.09999999999999999, 0.2000000000000001]
 ## infsup ("0xff", "0x1.ffp14")
 ##   @result{} [255, 32704]
 ## infsup ("1/3")
-##   @result{} [.33333333333333331, .33333333333333338]
+##   @result{} [0.3333333333333333, 0.33333333333333338]
 ## infsup ("[1/9, 47/11]")
-##   @result{} [.1111111111111111, 4.2727272727272734]
+##   @result{} [0.1111111111111111, 4.272727272727274]
 ## infsup ("7.3?9u")
-##   @result{} [7.2999999999999998, 8.200000000000002]
+##   @result{} [7.299999999999999, 8.200000000000002]
 ## infsup ("0??")
 ##   @result{} [Entire]
 ## infsup ("911??de-2")
@@ -88,7 +92,7 @@
 ## Keywords: interval
 ## Created: 2014-09-27
 
-function [x, isexact] = infsup (l, u)
+function [x, isexact, overflow] = infsup (l, u)
 
 if (nargin == 0)
     ## representation of the empty interval is always [inf,-inf]
@@ -199,6 +203,7 @@ endif
 ## check parameters and conversion to double precision
 isexact = true ();
 possiblyundefined = false (size (l));
+overflow = true (size (l));
 x.inf = zeros (size (l));
 x.sup = zeros (size (u));
 input.inf = l;
@@ -308,9 +313,11 @@ for [boundaries, key] = input
                 case {"-inf", "-infinity"}
                     x.(key) (i) = -inf;
                     possiblyundefined (i) = false ();
+                    overflow (i) = false;
                 case {"inf", "+inf", "infinity", "+infinity"}
                     x.(key) (i) = inf;
                     possiblyundefined (i) = false ();
+                    overflow (i) = false;
                 case "e"
                     isexact = false ();
                     switch key
@@ -483,6 +490,10 @@ if (any (any (not (isfinite (x.inf (x.inf == x.sup))), 1)))
            "illegal interval boundaries: infimum = supremum = +/- infinity");
 endif
 
+if (nargout >= 3)
+    overflow (x.inf > -inf & x.sup < inf) = false;
+endif
+
 ## check boundary order
 if (any (any (isfinite (x.inf (x.inf > x.sup)))) || ...
     any (any (isfinite (x.sup (x.inf > x.sup)))))
