@@ -1,4 +1,4 @@
-## Copyright 2014 Oliver Heimlich
+## Copyright 2014-2015 Oliver Heimlich
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -36,4 +36,12 @@ if (nargin ~= 1)
 endif
 
 result = (interval.inf == -inf & interval.sup == inf);
-return
+
+endfunction
+
+%!assert (isentire (entire ()));
+%!assert (isentire (intervalpart (entire ())));
+%!assert (not (isentire (empty ())));
+%!assert (not (isentire (intervalpart (empty ()))));
+
+%!warning assert (not (isentire (infsupdec (2, 1))));
