@@ -26,7 +26,7 @@
 ## @example
 ## @group
 ## log (infsup (2))
-##   @result{} [.6931471805599452, .6931471805599454]
+##   @result{} [0.6931471805599452, 0.6931471805599454]
 ## @end group
 ## @end example
 ## @seealso{@@infsup/exp, @@infsup/log2, @@infsup/log10}
@@ -43,7 +43,7 @@ if (nargin ~= 1)
     return
 endif
 
-x = x & infsup (0, inf);
+x = intersect (x, infsup (0, inf));
 
 ## log is monotonically increasing from (0, -inf) to (inf, inf)
 l = mpfr_function_d ('log', -inf, x.inf); # this works for empty intervals
