@@ -26,7 +26,7 @@
 ## @example
 ## @group
 ## log10 (infsup (2))
-##   @result{} [.30102999566398114, .3010299956639812]
+##   @result{} [0.3010299956639811, 0.3010299956639812]
 ## @end group
 ## @end example
 ## @seealso{@@infsup/pow10, @@infsup/log, @@infsup/log2}
@@ -43,7 +43,7 @@ if (nargin ~= 1)
     return
 endif
 
-x = x & infsup (0, inf);
+x = intersect (x, infsup (0, inf));
 
 ## log10 is monotonically increasing from (0, -inf) to (inf, inf)
 l = mpfr_function_d ('log10', -inf, x.inf); # this works for empty intervals
