@@ -57,18 +57,23 @@ if (not (isa (A, "infsup")))
 endif
 if (not (isa (b, "infsup")))
     b = infsup (b);
+elseif (isa (b, "infsupdec"))
+    ## Workaround for bug #42735
+    result = mldivide (A, b);
+    return
 endif
 
-if (not (issquare (A.inf)))
+if (isscalar (A.inf))
+    result = ldivide (A, b);
+    return
+elseif (not (issquare (A.inf)))
     error ("interval:InvalidOperand", "mldivide: Matrix is not square");
-endif
-if (rows (A.inf) ~= rows (b.inf))
+elseif (rows (A.inf) ~= rows (b.inf))
     error ("interval:InvalidOperand", ["mldivide: ", ...
         "nonconformant arguments ", ...
         "(op1 is " num2str(rows (A.inf)) "×" num2str(columns (A.inf)) ",", ...
         " op2 is " num2str(rows (b.inf)) "×" num2str(columns (b.inf)) ")"]);
-endif
-if (isempty (A.inf))
+elseif (isempty (A.inf))
     result = infsup (zeros (0, columns (b.inf)));
     return
 endif
@@ -269,7 +274,7 @@ function [x, verified] = verify_and_refine (x0, C, cfg, accuracy)
         ## Iterative refinement
         for p = 1 : cfg.maxIterRef
             y = x;
-            x = (x0 + mtimes (C, x, accuracy)) & x;
+            x = intersect (x0 + mtimes (C, x, accuracy), x);
             
             if (p == cfg.maxIterRef)
                 break
