@@ -26,8 +26,7 @@
 ## Warning: This function is not defined by IEEE 1788.
 ##
 ## Accuracy: The result is a valid enclosure.  The result is tightest for
-## @var{Y} in @{0, 1@} and nearly tightest for @var{Y} = 2 (within 1.5 ULPs of
-## the exact result).
+## @var{Y} in @{0, 1, 2@}.
 ##
 ## @example
 ## @group
