@@ -57,6 +57,10 @@ if (not (isa (x, "infsup")))
 endif
 if (not (isa (y, "infsup")))
     y = infsup (y);
+elseif (isa (y, "infsupdec"))
+    ## Workaround for bug #42735
+    result = mtimes (x, y);
+    return
 endif
 
 if (isscalar (x) || isscalar (y))
@@ -106,12 +110,15 @@ function C = fast_mtimes (A, B)
 [mB, rB] = rad (B);
 rhoA = sign (mA) .* min (abs (mA), rA);
 rhoB = sign (mB) .* min (abs (mB), rB);
-__setround__ (+1); # rounding towards +inf
-rC = abs (mA) * rB + rA * (abs (mB) + rB) + (-abs (rhoA)) * abs (rhoB);
-u = mA * mB + rhoA * rhoB + rC;
-__setround__ (-1); # rounding towards -inf
-l = mA * mB + rhoA * rhoB - rC;
-__setround__ (0); # restore default rounding mode (to nearest)
+unwind_protect
+    __setround__ (+1); # rounding towards +inf
+    rC = abs (mA) * rB + rA * (abs (mB) + rB) + (-abs (rhoA)) * abs (rhoB);
+    u = mA * mB + rhoA * rhoB + rC;
+    __setround__ (-1); # rounding towards -inf
+    l = mA * mB + rhoA * rhoB - rC;
+unwind_protect_cleanup
+    __setround__ (0); # restore default rounding mode (to nearest)
+end_unwind_protect
 
 C = infsup (l, u);
 
