@@ -45,7 +45,7 @@ endif
 
 even = mod (n, 2) == 0;
 if (even)
-    x = x & infsup (0, inf);
+    x = intersect (x, infsup (0, inf));
 endif
 
 switch sign (n)
@@ -115,7 +115,7 @@ switch sign (n)
             l (emptyresult | notnegative) = inf;
             u (emptyresult | notnegative) = -inf;
             
-            result = result | infsup (-u, -l);
+            result = union (result, infsup (-u, -l));
         endif
     
     otherwise
