@@ -71,11 +71,13 @@ if (p == 0) # x^p == 1
 else
     even = mod (p, 2) == 0;
     if (even)
-        result = (x & nthroot (c & infsup (0, inf), p)) ...
-               | (x & -nthroot (c & infsup (0, inf), p));
+        result = union (...
+                intersect (x, nthroot (intersect (c, infsup (0, inf)), p)), ...
+                intersect (x, -nthroot (intersect (c, infsup (0, inf)), p)));
     else
-        result = (x & nthroot (c & infsup (0, inf), p)) ...
-               | (x & nthroot (c & infsup (-inf, 0), p));
+        result = union (...
+                intersect (x, nthroot (intersect (c, infsup (0, inf)), p)), ...
+                intersect (x, nthroot (intersect (c, infsup (-inf, 0)), p)));
     endif
 endif
 
