@@ -28,7 +28,7 @@
 ## @example
 ## @group
 ## powrev1 (infsup (2, 5), infsup (3, 6))
-##   @result{} [1.2457309396155171, 2.4494897427831784]
+##   @result{} [1.245730939615517, 2.449489742783179]
 ## @end group
 ## @end example
 ## @seealso{@@infsup/pow}
@@ -57,8 +57,8 @@ if (not (isa (x, "infsup")))
     x = infsup (x);
 endif
 
-x = x & infsup (0, inf);
-c = c & infsup (0, inf);
+x = intersect (x, infsup (0, inf));
+c = intersect (c, infsup (0, inf));
 
 ## Broadcast parameters if necessary
 if (isscalar (x.inf))
