@@ -28,7 +28,7 @@
 ## @example
 ## @group
 ## powrev2 (infsup (2, 5), infsup (3, 6))
-##   @result{} [.6826061944859851, 2.5849625007211566]
+##   @result{} [0.6826061944859851, 2.5849625007211566]
 ## @end group
 ## @end example
 ## @seealso{@@infsup/pow}
@@ -57,8 +57,8 @@ if (not (isa (y, "infsup")))
     y = infsup (y);
 endif
 
-a = a & infsup (0, inf);
-c = c & infsup (0, inf);
+a = intersect (a, infsup (0, inf));
+c = intersect (c, infsup (0, inf));
 
 ## Broadcast parameters if necessary
 if (isscalar (y.inf))
