@@ -47,6 +47,10 @@ if (not (isa (x, "infsup")))
 endif
 if (not (isa (y, "infsup")))
     y = infsup (y);
+elseif (isa (y, "infsupdec"))
+    ## Workaround for bug #42735
+    result = rdivide (x, y);
+    return
 endif
 
 ## Resize, if scalar × matrix
