@@ -1,4 +1,4 @@
-## Copyright 2014-2015 Oliver Heimlich
+## Copyright 2015 Oliver Heimlich
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -19,6 +19,9 @@
 ## 
 ## Compute the square root (for all non-negative numbers).
 ##
+## Since intervals are only defined for real numbers, this function and
+## @code{realsqrt} are equivalent.
+##
 ## Accuracy: The result is a tight enclosure.
 ##
 ## @example
@@ -27,23 +30,21 @@
 ##   @result{} [0, 2]
 ## @end group
 ## @end example
-## @seealso{@@infsup/sqr, @@infsup/pow}
+## @seealso{@@infsup/sqr, @@infsup/pow, @@infsup/nthroot, @@infsup/cbrt}
 ## @end deftypefn
 
 ## Author: Oliver Heimlich
 ## Keywords: interval
-## Created: 2014-10-01
+## Created: 2015-03-15
 
 function result = sqrt (x)
 
-l = mpfr_function_d ('sqrt', -inf, max (0, x.inf));
-u = mpfr_function_d ('sqrt', +inf, max (0, x.sup));
+if (nargin ~= 1)
+    print_usage ();
+    return
+endif
 
-emptyresult = isempty (x) | x.sup < 0;
-l (emptyresult) = inf;
-u (emptyresult) = -inf;
-
-result = infsup (l, u);
+result = realsqrt (x);
 
 endfunction
 
