@@ -24,7 +24,7 @@
 ## @example
 ## @group
 ## atan2 (infsupdec (1), infsupdec (-1))
-##   @result{} [2.3561944901923448, 2.3561944901923453]_com
+##   @result{} [2.3561944901923448, 2.356194490192346]_com
 ## @end group
 ## @end example
 ## @seealso{@@infsupdec/tan}
@@ -57,7 +57,7 @@ if (isnai (y))
     return
 endif
 
-result = infsupdec (atan2 (intervalpart (y), intervalpart (x)));
+result = newdec (atan2 (intervalpart (y), intervalpart (x)));
 result.dec = mindec (result.dec, y.dec, x.dec);
 
 ## The function is discontinuous for x <= 0 and y == 0
