@@ -24,7 +24,7 @@
 ## @example
 ## @group
 ## cos (infsupdec (1))
-##   @result{} [.5403023058681396, .5403023058681398]_com
+##   @result{} [0.5403023058681396, 0.5403023058681398]_com
 ## @end group
 ## @end example
 ## @seealso{@@infsupdec/acos, @@infsupdec/sec, @@infsupdec/cosh}
@@ -46,7 +46,7 @@ if (isnai (x))
     return
 endif
 
-result = infsupdec (cos (intervalpart (x)));
+result = newdec (cos (intervalpart (x)));
 ## cos is defined and continuous everywhere
 result.dec = mindec (result.dec, x.dec);
 
