@@ -86,7 +86,7 @@ if ((min (size (x.dec, 1), size (y.dec, 1)) > 1 && ...
     error ("interval:InvalidOperand", "dot: sizes of X and Y must match")
 endif
 
-result = infsupdec (dot (intervalpart (x), intervalpart (y), dim));
+result = newdec (dot (intervalpart (x), intervalpart (y), dim));
 result.dec = mindec (result.dec, ...
                      reducedec (x.dec, dim), ...
                      reducedec (y.dec, dim));
