@@ -26,7 +26,7 @@
 ## floor (infsupdec (2.5, 3.5))
 ##   @result{} [2, 3]_def
 ## floor (infsupdec (-0.5, 5))
-##   @result{} [-1, 5]_def
+##   @result{} [-1, +5]_def
 ## @end group
 ## @end example
 ## @seealso{@@infsupdec/ceil, @@infsupdec/round, @@infsupdec/roundb, @@infsupdec/fix}
@@ -48,7 +48,7 @@ if (isnai (x))
     return
 endif
 
-result = infsupdec (floor (intervalpart (x)));
+result = newdec (floor (intervalpart (x)));
 result.dec = mindec (result.dec, x.dec);
 
 ## Between two integral numbers the function is constant, thus continuous
