@@ -28,9 +28,9 @@
 ## @example
 ## @group
 ## fma (infsupdec (1+eps), infsupdec (7), infsupdec ("0.1"))
-##   @result{} [7.1000000000000014, 7.1000000000000024]_com
+##   @result{} [7.100000000000001, 7.100000000000003]_com
 ## infsupdec (1+eps) * infsupdec (7) + infsupdec ("0.1")
-##   @result{} [7.1000000000000005, 7.1000000000000024]_com
+##   @result{} [7.1, 7.100000000000003]_com
 ## @end group
 ## @end example
 ## @seealso{@@infsupdec/plus, @@infsupdec/mtimes}
@@ -70,7 +70,7 @@ if (isnai (z))
     return
 endif
 
-result = infsupdec (...
+result = newdec (...
         fma (intervalpart (x), intervalpart (y), intervalpart (z)));
 ## fma is defined and continuous everywhere
 result.dec = mindec (result.dec, x.dec, y.dec, z.dec);
