@@ -21,6 +21,7 @@
 ## @deftypefnx {Function File} {[@var{X}, @var{ISEXACT}] =} infsupdec (@var{S})
 ## @deftypefnx {Function File} {[@var{X}, @var{ISEXACT}] =} infsupdec (@var{L}, @var{U})
 ## @deftypefnx {Function File} {[@var{X}, @var{ISEXACT}] =} infsupdec (@var{L}, @var{U}, @var{D})
+## @deftypefnx {Function File} {[@var{X}, @var{ISEXACT}] =} infsupdec (@var{I}, @var{D})
 ## 
 ## Create a decorated interval from boundaries.  Convert boundaries to double
 ## precision.
@@ -32,14 +33,18 @@
 ## @code{infsupdec (@var{M}, @var{M}, @var{D})}.  The syntax
 ## @code{infsupdec (@var{S})} parses a possibly decorated interval literal in
 ## inf-sup form or as a special value, where @code{infsupdec ("[S1, S2]")} is
-## equivalent to @code{infsupdec ("S1", "S2")} and
+## equivalent to @code{infsupdec ("S1", "S2")} and, if [S1, S2]_D is a valid
+## interval literal,
 ## @code{infsupdec ("[S1, S2]_D")} is equivalent to
-## @code{infsupdec ("S1", "S2", "D")}.  A second, logical output @var{ISEXACT}
-## indicates if @var{X}'s boundaries both have been converted without precision
-## loss.
+## @code{infsupdec ("S1", "S2", "D")}.  The syntax 
+## @code{infsupdec (@var{I}, @var{D})} overrides an interval @var{I}'s
+## decoration with a new decoration @var{D}.  A second, logical output
+## @var{ISEXACT} indicates if @var{X}'s boundaries both have been converted
+## without precision loss and without changes to the optional, desired
+## decoration.
 ##
-## If construction fails, the special value [NaI], “not an interval,” will be
-## returned and a warning message will be raised.  [NaI] is equivalent to
+## If construction fails, the special value NaI, “not an interval,” will be
+## returned and a warning message will be raised.  NaI is equivalent to
 ## [Empty] together with an ill-formed decoration.
 ##
 ## Each boundary can be provided in the following formats: literal constants
@@ -60,9 +65,18 @@
 ## tight enclosure will be computed.  int64 and uint64 numbers of high
 ## magnitude (> 2^53) can also be affected from precision loss.
 ##
+## The decoration @var{D} must be any of @code{com}, @code{dac}, @code{def},
+## @code{trv}, or @code{ill}.  Illegal decorations within interval literals
+## will produce NaIs, whereas illegal decorations provided as an additional
+## function parameter will be automatically adjusted.
+##
+## For the creation of interval matrices, arguments may be provided as (1) cell 
+## arrays with arbitrary/mixed types, (2) numeric matrices, or (3) string
+## column vectors.  Scalar values do broadcast.
+##
 ## Non-standard behavior: This class constructor is not described by IEEE 1788,
-## however it implements the IEEE 1788 functions newDec, setDec, 
-## numsToInterval, and textToInterval.
+## however it implements the IEEE 1788 functions setDec, numsToInterval, and
+## textToInterval.
 ## 
 ## @example
 ## @group
@@ -73,12 +87,12 @@
 ## x = infsupdec (2, 3)
 ##   @result{} [2, 3]_com
 ## y = infsupdec ("0.1")
-##   @result{} [.09999999999999999, .10000000000000001]_com
+##   @result{} [0.09999999999999999, 0.1000000000000001]_com
 ## z = infsupdec ("0.1", "0.2")
-##   @result{} [.09999999999999999, .20000000000000002]_com
+##   @result{} [0.09999999999999999, 0.2000000000000001]_com
 ## @end group
 ## @end example
-## @seealso{exacttointerval}
+## @seealso{exacttointerval, hull, midrad, @@infsup/newdec}
 ## @end deftypefn
 
 ## Author: Oliver Heimlich
@@ -119,24 +133,42 @@ try
         endswitch
     elseif (nargin == 1 && iscell (varargin {1}))
         ## Parse possibly decorated interval literals
+        chars = cellfun ("ischar", varargin {1});
+        varargin {1} (chars) = cellfun (@strsplit, ...
+                                        varargin {1} (chars), ...
+                                        {"_"}, ...
+                                        "UniformOutput", false);
+        if (any (any (cellfun ("size", varargin {1} (chars), 2) > 2)))
+            ## More than 2 underscores in any literal
+            error ("interval:InvalidOperand", ...
+                   "illegal decorated interval literal")
+        endif
+        ## Extract decoration
         dec = cell (size (varargin {1}));
         dec (:) = {""};
-        for i = 1 : numel (varargin {1})
-            if (ischar (varargin {1} {i}))
-                literal = strsplit (varargin {1} {i}, "_");
-                if (length (literal) == 2) # decorated interval literal
-                    varargin {1} {i} = literal {1};
-                    dec {i} = literal {2};
-                elseif (length (literal) > 2)
-                    error ("interval:InvalidOperand", ...
-                           "illegal decorated interval literal")
-                endif
-            endif
-        endfor
+        hasdec = false (size (varargin {1}));
+        hasdec (chars) = cellfun ("size", varargin {1} (chars), 2) == 2;
+        dec (hasdec) = cellfun (@(x) x {2}, varargin {1} (hasdec), ...
+                                "UniformOutput", false);
+        varargin {1} (chars) = cellfun (@(x) x {1}, varargin {1} (chars), ...
+                                        "UniformOutput", false);
         
         ## Note: The representation of NaI, will trigger an error in the infsup
         ## constructor
-        [bare, isexact] = infsup (varargin {1});
+        [bare, isexact, overflow] = infsup (varargin {1});
+        
+        ## Silently fix decorated interval literals when overflow occurred
+        dec (overflow & strcmpi (dec, "com")) = "dac";
+        
+        ## Validate decorations of interval literals
+        if (any (any (...
+            ## Unbound common intervals are illegal
+            (strcmpi (dec, "com") & not (iscommoninterval (bare))) | ...
+            ## Empty intervals must carry trv
+            (not (strcmpi (dec, "trv") | strcmp (dec, "")) & isempty (bare)))))
+            error ("interval:InvalidOperand", ...
+                   "illegal decorated interval literal")
+        endif
     else
         ## Undecorated interval boundaries
         dec = {""};
@@ -151,13 +183,18 @@ try
                 elseif (isa (varargin {1}, "infsup"))
                     bare = varargin {1};
                     isexact = true ();
+                    if (not (all (all (isempty (bare)))))
+                        warning ("interval:ImplicitPromote", ...
+                                ["Implicitly decorated bare interval; ", ...
+                                 "resulting decoration may be wrong"]);
+                    endif
                 else
                     [bare, isexact] = infsup (varargin {1});
                 endif
             case 2
                 [bare, isexact] = infsup (varargin {1}, varargin {2});
             otherwise
-                error ("interval:InvalidOperand", "too many arguments")
+                print_usage ();
         endswitch
     endif
     
@@ -205,12 +242,20 @@ try
         error ("interval:InvalidOperand", "illegal decoration");
     endif
 catch
-    if (not (strcmp ("interval:NaI", lasterror.identifier)))
-        ## The bare inverval:NaI error can only occur, if the interval literal
-        ## [NaI] is observed. In that particular case, we must not issue a
-        ## warning.
-        warning ("interval:NaI", lasterror.message);
-    endif
+    switch lasterror.identifier
+        case "Octave:invalid-fun-call"
+            print_usage ();
+        case "interval:NaI"
+            ## The bare inverval:NaI error can only occur, if the interval
+            ## literal [NaI] is observed. In that particular case, we must not
+            ## issue a warning.
+        case {"interval:PossiblyUndefined", ...
+              "interval:ImplicitPromote"}
+            ## The user has set these warnings to error, which we must respect
+            rethrow (lasterror)
+        otherwise
+            warning ("interval:NaI", lasterror.message);
+    endswitch
     ## NaI representation is unique.
     bare = infsup ();
     dec = {"ill"};
@@ -221,9 +266,18 @@ x.dec = dec;
 
 x = class (x, "infsupdec", bare);
 
-## Enable all mixed mode functions to use decorated variants
-## FIXME This does not work for operators atm,
-## see http://savannah.gnu.org/bugs/?42735
+## Enable all mixed mode functions to use decorated variants with implicit
+## conversion from bare to decorated intervals.
+##
+## There is bug #42735 in GNU Octave core, which makes this a little
+## complicated: When [infsup] [operator] [infsupdec] syntax is used, the
+## decoration from the second argument would be lost, because the bare
+## implementation for the operator is evaluated. However, sufficient runtime
+## checks have been placed in the overloaded class operator implementations of
+## the infsup class as a workaround.
+##
+## The workaround is necessary, because otherwise this could lead to wrong
+## results, which is catastrophic for a verified computation package.
 superiorto ("infsup");
 
 endfunction
@@ -232,7 +286,9 @@ endfunction
 %!  assert (isnai (infsupdec ("[nai]"))); # quiet [NaI]
 %!warning assert (isnai (infsupdec (3, 2)));
 %!warning assert (isnai (infsupdec ("Flugeldufel")));
-%!test "decoration adjustments";
+%!warning assert (isnai (infsupdec ("[1, Inf]_com")));
+%!warning assert (isnai (infsupdec ("[Empty]_def")));
+%!test "decoration adjustments, setDec function";
 %!  assert (inf (infsupdec (42, inf, "com")), 42);
 %!  assert (sup (infsupdec (42, inf, "com")), inf);
 %!  assert (strcmp (decorationpart (infsupdec (42, inf, "com")), "dac"));
@@ -242,6 +298,10 @@ endfunction
 %!  assert (inf (infsupdec (inf, -inf, "def")), inf);
 %!  assert (sup (infsupdec (inf, -inf, "def")), -inf);
 %!  assert (strcmp (decorationpart (infsupdec (inf, -inf, "def")), "trv"));
+%!test "overflow";
+%!  assert (inf (infsupdec ("[1, 1e999]_com")), 1);
+%!  assert (sup (infsupdec ("[1, 1e999]_com")), inf);
+%!  assert (strcmp (decorationpart (infsupdec ("[1, 1e999]_com")), "dac"));
 %!test "decorated interval literal";
 %!  assert (inf (infsupdec ("[2, 3]_def")), 2);
 %!  assert (sup (infsupdec ("[2, 3]_def")), 3);
