@@ -1,4 +1,4 @@
-## Copyright 2014 Oliver Heimlich
+## Copyright 2014-2015 Oliver Heimlich
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -39,9 +39,12 @@ if (nargin ~= 1)
 endif
 
 if (isnai (x))
-    error ("interval comparison with NaI")
+    result = false ();
+else
+    result = isempty (intervalpart (x));
 endif
 
-result = isempty (intervalpart (x));
+endfunction
 
-return
\ No newline at end of file
+%!assert (isempty (infsupdec (inf, -inf)));
+%!assert (not (isempty (infsupdec (1, 2))));
