@@ -26,7 +26,7 @@
 ## @example
 ## @group
 ## log (infsupdec (2))
-##   @result{} [.6931471805599452, .6931471805599454]_com
+##   @result{} [0.6931471805599452, 0.6931471805599454]_com
 ## @end group
 ## @end example
 ## @seealso{@@infsupdec/exp, @@infsupdec/log2, @@infsupdec/log10}
@@ -48,11 +48,11 @@ if (isnai (x))
     return
 endif
 
-result = infsupdec (log (intervalpart (x)));
+result = newdec (log (intervalpart (x)));
 result.dec = mindec (result.dec, x.dec);
 
 ## log is continuous everywhere, but defined for x > 0 only
-result.dec (not (interior (x, infsup(0, inf)))) = "trv";
+result.dec (not (interior (x, infsupdec (0, inf)))) = "trv";
 
 endfunction
 
