@@ -26,7 +26,7 @@
 ## @example
 ## @group
 ## log10 (infsupdec (2))
-##   @result{} [.30102999566398114, .3010299956639812]_com
+##   @result{} [0.3010299956639811, 0.3010299956639812]_com
 ## @end group
 ## @end example
 ## @seealso{@@infsupdec/pow10, @@infsupdec/log, @@infsupdec/log2}
@@ -48,11 +48,11 @@ if (isnai (x))
     return
 endif
 
-result = infsupdec (log10 (intervalpart (x)));
+result = newdec (log10 (intervalpart (x)));
 result.dec = mindec (result.dec, x.dec);
 
 ## log10 is continuous everywhere, but defined for x > 0 only
-result.dec (not (interior (x, infsup(0, inf)))) = "trv";
+result.dec (not (interior (x, infsupdec (0, inf)))) = "trv";
 
 endfunction
 
