@@ -48,11 +48,11 @@ if (isnai (x))
     return
 endif
 
-result = infsupdec (log2 (intervalpart (x)));
+result = newdec (log2 (intervalpart (x)));
 result.dec = mindec (result.dec, x.dec);
 
 ## log2 is continuous everywhere, but defined for x > 0 only
-result.dec (not (interior (x, infsup(0, inf)))) = "trv";
+result.dec (not (interior (x, infsupdec (0, inf)))) = "trv";
 
 endfunction
 
