@@ -66,10 +66,15 @@ if (isempty (x.dec) || isempty (y.dec))
     return
 endif
 
+if (isscalar (x) || isscalar (y))
+    result = times (x, y);
+    return
+endif
+
 if (nargin == 2)
-    result = infsupdec (mtimes (intervalpart (x), intervalpart (y)));
+    result = newdec (mtimes (intervalpart (x), intervalpart (y)));
 else
-    result = infsupdec (mtimes (intervalpart (x), intervalpart (y), accuracy));
+    result = newdec (mtimes (intervalpart (x), intervalpart (y), accuracy));
 endif
 
 dec_x = reducedec (x.dec, 2);
