@@ -45,8 +45,8 @@
 ## c = infsupdec (1);
 ## b = infsupdec (-inf, inf);
 ## [u, v] = mulrev (b, c)
-##   @result{} [-Inf, 0]_trv
-##   @result{} [0, Inf]_trv
+##   @result{} u = [-Inf, 0]_trv
+##             v = [0, Inf]_trv
 ## @end group
 ## @end example
 ## @seealso{@@infsupdec/times}
@@ -94,7 +94,7 @@ if (nargout < 2)
     u = infsupdec (u, "trv");
 else
     [u, v] = mulrev (intervalpart (b), intervalpart (c), intervalpart (x));
-    u = infsupdec (u);
+    u = newdec (u);
     u.dec = mindec (u.dec, b.dec, c.dec);
     u.dec (isempty (b) | isempty (c) | ismember (0, b)) = "trv";
     
