@@ -36,14 +36,14 @@ if (nargin ~= 2)
     return
 endif
 if (not (isa (x, "infsupdec")))
-    x = infsup (x);
+    x = infsupdec (x);
 endif
 if (isnai (x))
     result = x;
     return
 endif
 
-result = infsupdec (nthroot (intervalpart (x), n));
+result = newdec (nthroot (intervalpart (x), n));
 result.dec = mindec (result.dec, x.dec);
 
 ## nthroot is continuous everywhere, but not defined everywhere
