@@ -27,7 +27,7 @@
 ## round (infsupdec (2.5, 3.5))
 ##   @result{} [3, 4]_def
 ## round (infsupdec (-0.5, 5))
-##   @result{} [-1, 5]_def
+##   @result{} [-1, +5]_def
 ## @end group
 ## @end example
 ## @seealso{@@infsupdec/floor, @@infsupdec/ceil, @@infsupdec/roundb, @@infsupdec/fix}
@@ -49,7 +49,7 @@ if (isnai (x))
     return
 endif
 
-result = infsupdec (round (intervalpart (x)));
+result = newdec (round (intervalpart (x)));
 result.dec = mindec (result.dec, x.dec);
 
 ## Round is like a scaled fix function
