@@ -27,7 +27,7 @@
 ##   @result{} [1]_com
 ## sign (infsupdec (0, 5))
 ##   @result{} [0, 1]_def
-## sign (infsup (-17))
+## sign (infsupdec (-17))
 ##   @result{} [-1]_com
 ## @end group
 ## @end example
@@ -49,7 +49,7 @@ if (isnai (x))
     return
 endif
 
-result = infsupdec (sign (intervalpart (x)));
+result = newdec (sign (intervalpart (x)));
 result.dec = mindec (result.dec, x.dec);
 
 ## sign is defined everywhere and continuous for x ~= 0
