@@ -24,7 +24,7 @@
 ## @example
 ## @group
 ## sin (infsupdec (1))
-##   @result{} [.8414709848078965, .8414709848078967]_com
+##   @result{} [0.8414709848078965, 0.8414709848078967]_com
 ## @end group
 ## @end example
 ## @seealso{@@infsupdec/asin, @@infsupdec/csc, @@infsupdec/sinh}
@@ -46,7 +46,7 @@ if (isnai (x))
     return
 endif
 
-result = infsupdec (sin (intervalpart (x)));
+result = newdec (sin (intervalpart (x)));
 ## sin is defined and continuous everywhere
 result.dec = mindec (result.dec, x.dec);
 
