@@ -67,9 +67,9 @@ switch (S (1).type)
         error ("interval cannot be indexed with {}")
     case "."
         if (any (strcmp (S(1).subs, methods ("infsupdec"))))
-            functionname = ["@infsupdec/", S(1).subs];
+            functionname = ["@infsupdec", filesep(),  S(1).subs];
         elseif (any (strcmp (S(1).subs, methods ("infsup"))))
-            functionname = ["@infsup/", S(1).subs];
+            functionname = ["@infsup", filesep(), S(1).subs];
         else
             error (["interval property ‘", S(1).subs, "’ is unknown"])
         endif
